<?php
// no direct access
defined( '_JEXEC' ) or die;

/**
 * VikAppointments - Services Difficulty Joomla! plugin.
 * 
 * @since 1.0
 */
class plgVikAppointmentsServicesdifficulty extends JPlugin
{
    /**
     * Load the language file on instantiation. Note this is only available in Joomla 3.1 and higher.
     * If you want to support 3.0 series you must override the constructor
     *
     * @var    boolean
     * @since  3.1
     */
    protected $autoloadLanguage = true;

    /**
     * The application instance.
     * 
     * @var    JApplication
     * @since  1.5
     */
    protected $app;

    /**
     * The database driver instance.
     * 
     * @var    JDatabaseDriver
     * @since  1.5
     */
    protected $db;

    /**
     * Extend the service management page.
     * 
     * @param   object  $view  The view instance.
     * 
     * @return  array   An associative array containing new fields to introduce.
     */
    public function onDisplayViewService($view)
    {
        return [
            // inject parameters within the details fieldset
            'service' => [
                // create difficulty input (the key is equals to the parameter name)
                'difficulty' => [
                    // display an input number
                    'type' => 'number',
                    // display the input label
                    'label' => JText::_('PLG_VAP_SERDIFF_INPUT_LABEL'),
                    // display an optional description of the field
                    'help' => JText::_('PLG_VAP_SERDIFF_INPUT_DESC'),
                    // define the minimum supported value (0%)
                    'min' => 0,
                    // define the maximum supported value (100%)
                    'max' => 100,
                    // define the number of supported steps
                    'step' => 1,
                    // define the default value to use (50%)
                    'default' => 50,
                    // define the last saved value, if any
                    'value' => isset($view->service->difficulty) ? (int) $view->service->difficulty : null,
                ],
            ],
        ];
    }

    /**
     * Bind the service data before save.
     * 
     * @param   array|object  &$data  The data to save.
     * 
     * @return  bool          True on success, false otherwise.
     */
    public function onBeforeSaveService(&$data)
    {
        $data = (array) $data;

        // get service difficulty from request
        $difficulty = $this->app->input->getUint('difficulty', null);

        if (!is_null($difficulty))
        {
            // difficulty specified, bind it into the array to save
            $data['difficulty'] = $difficulty;
        }

        return true;
    }

    /**
     * Build service data before displaying the service details page.
     * 
     * @param   object  $service  The service data.
     * 
     * @return  void
     */
    public function onBuildServiceSearchData($service)
    {
        // check whether the service specifies a difficulty
        if (!empty($service->difficulty))
        {
            $root = JUri::root() . 'plugins/vikappointments/servicesdifficulty/assets/';

            // yep, load our assets
            JHtml::_('script', $root . 'script.js', ['version' => '1.0']);
            JHtml::_('stylesheet', $root . 'style.css', ['version' => '1.0']);

            // assign service difficulty to a global variable in order to make it accessible from our script file
            JFactory::getDocument()->addScriptDeclaration("window['serviceDifficulty'] = {$service->difficulty};");

            // localize "Difficulty" label for the script file
            JText::script('PLG_VAP_SERDIFF_INPUT_LABEL');
        }
    }
}
